@@ -1,7 +1,7 @@
 #!/bin/sh
 echo 'name: haskeline
-version: 0.6.4.7
-id: haskeline-0.6.4.7-08f3dc18120deddd3fcdc27c5f52a01e
+version: 0.7.0.3
+id: haskeline-0.7.0.3-54d87a797931469bb092e5cc38909b92
 
 license: BSD3
 copyright: (c) Judah Jacobson
@@ -22,15 +22,16 @@ pkgpath: devel/hs-haskeline
 exposed: True
 exposed-modules: System.Console.Haskeline
                  System.Console.Haskeline.Completion
-                 System.Console.Haskeline.Encoding
                  System.Console.Haskeline.MonadException
                  System.Console.Haskeline.History System.Console.Haskeline.IO
-hidden-modules: System.Console.Haskeline.Backend.Terminfo
-                System.Console.Haskeline.Backend.WCWidth
+hidden-modules: System.Console.Haskeline.Recover
+                System.Console.Haskeline.Backend.Terminfo
                 System.Console.Haskeline.Backend.Posix
-                System.Console.Haskeline.Backend.IConv
+                System.Console.Haskeline.Backend.Posix.Encoder
                 System.Console.Haskeline.Backend.DumbTerm
-                System.Console.Haskeline.Backend System.Console.Haskeline.Command
+                System.Console.Haskeline.Backend
+                System.Console.Haskeline.Backend.WCWidth
+                System.Console.Haskeline.Command
                 System.Console.Haskeline.Command.Completion
                 System.Console.Haskeline.Command.History
                 System.Console.Haskeline.Command.KillRing
@@ -41,28 +42,26 @@ hidden-modules: System.Console.Haskeline.Backend.Terminfo
                 System.Console.Haskeline.Term System.Console.Haskeline.Command.Undo
                 System.Console.Haskeline.Vi
 trusted: False
-import-dirs: /usr/local/lib/ghc/haskeline-0.6.4.7
-library-dirs: /usr/local/lib/ghc/haskeline-0.6.4.7
-hs-libraries: HShaskeline-0.6.4.7
-extra-libraries: iconv
+import-dirs: /usr/local/lib/ghc/haskeline-0.7.0.3
+library-dirs: /usr/local/lib/ghc/haskeline-0.7.0.3
+hs-libraries: HShaskeline-0.7.0.3
+extra-libraries:
 extra-ghci-libraries:
-include-dirs: /usr/local/lib/ghc/haskeline-0.6.4.7/include
-includes: h_iconv.h
-depends: base-4.5.1.0-f38bf31a759416ec7b167d6dc132959a
-         bytestring-0.9.2.1-4f95f32adc23f1bc25c472a646e99581
-         containers-0.4.2.1-75f143aa39a3e77a1ce2300025bdd8ce
-         directory-1.1.0.2-da0a8c62c2b42ae7a3b538f5fee58422
-         extensible-exceptions-0.1.1.4-3d9bd197c43329612c640f24179a7f19
-         filepath-1.3.0.0-f998e5510c76a98913f57b14b4f16c57
-         mtl-2.1.2-02e701f9b1590ee88a0b5b0bd5d93a29
-         terminfo-0.3.1.3-e63a5289027696968365d5f466f316a6
-         unix-2.5.1.1-0adea5be633a6b5a124519287d54626d
-         utf8-string-0.3.8-2777416918ab74e3e486858d8ef2fdf6
+include-dirs:
+includes:
+depends: base-4.6.0.1-03845c6da2a0b3b4d0d49cc26c0cd3c0
+         bytestring-0.10.0.2-9e8b487747800a4255d6ff7915c5210f
+         containers-0.5.0.0-ab1dae9a94cd3cc84e7b2805636ebfa2
+         directory-1.2.0.1-ee04c884b72040489d2e2ca6dd62e6ac
+         filepath-1.3.0.1-b12cbe18566fe1532a1fda4c85e31cbe
+         terminfo-0.3.1.3-ea016ad790de7f73f62787aa60375fb0
+         transformers-0.3.0.0-ff2bb6ac67241ebb987351a3db564af0
+         unix-2.6.0.1-2939d4be83b53d31ca104e0487b1ef98
 hugs-options:
 cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-haskeline-0.6.4.7/html/haskeline.haddock
-haddock-html: /usr/local/share/doc/hs-haskeline-0.6.4.7/html
-' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
+haddock-interfaces: /usr/local/share/doc/hs-haskeline-0.7.0.3/html/haskeline.haddock
+haddock-html: /usr/local/share/doc/hs-haskeline-0.7.0.3/html
+' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
